summaryrefslogtreecommitdiffstats
path: root/src/micro/micropackage.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
commit87a016680e3677da3993f333561e79eb0cead7d5 (patch)
treecbda2b4df8b8ee0d8d1617e6c75bec1e3ee0ccba /src/micro/micropackage.h
parent6ce3d1ad09c1096b5ed3db334e02859e45d5c32b (diff)
downloadktechlab-87a016680e3677da3993f333561e79eb0cead7d5.tar.gz
ktechlab-87a016680e3677da3993f333561e79eb0cead7d5.zip
TQt4 port ktechlab
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktechlab@1238801 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/micro/micropackage.h')
-rw-r--r--src/micro/micropackage.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/micro/micropackage.h b/src/micro/micropackage.h
index 0dc98fe..11b9a09 100644
--- a/src/micro/micropackage.h
+++ b/src/micro/micropackage.h
@@ -11,10 +11,10 @@
#ifndef PICPACKAGES_H
#define PICPACKAGES_H
-#include <qstring.h>
-#include <qstringlist.h>
+#include <tqstring.h>
+#include <tqstringlist.h>
-#include <qmap.h>
+#include <tqmap.h>
/**
@author David Saxton
@@ -34,17 +34,17 @@ public:
};
PicPin();
- PicPin( const QString &_pinID, PicPin::pin_type _type, const QString &_portName = "", int _portPosition = -1 );
+ PicPin( const TQString &_pinID, PicPin::pin_type _type, const TQString &_portName = "", int _portPosition = -1 );
PicPin::pin_type type;
- QString pinID; // Id of pin, eg 'MCLR'
+ TQString pinID; // Id of pin, eg 'MCLR'
// For bidir (io) pins
- QString portName; // Name of port, eg 'PORTA'
+ TQString portName; // Name of port, eg 'PORTA'
int portPosition; // Position in port
};
-typedef QMap<int, PicPin> PicPinMap;
+typedef TQMap<int, PicPin> PicPinMap;
/**
@short Describes the PIC package (i.e. pins)
@@ -59,30 +59,30 @@ public:
/**
* Assigns a pin to a position in the package.
*/
- void assignPin( int pinPosition, PicPin::pin_type type, const QString& pinID, const QString& portName = "", int portPosition = -1);
+ void assignPin( int pinPosition, PicPin::pin_type type, const TQString& pinID, const TQString& portName = "", int portPosition = -1);
/**
* Returns the pins of the given type(s). If portName is not specified, all pins will be returned;
* not just those belonging to a given port. pin_type's can be OR'ed together
* e.g. pins( PicPin::type_input | PicPin::type_bidir, "PORTA" ) will return all bidirectional or
* input pins belonging to PORTA. If pinType is 0, then this will return all pins
*/
- PicPinMap pins( uint pinType = 0, const QString& portName = "" );
+ PicPinMap pins( uint pinType = 0, const TQString& portName = "" );
/**
* Returns just a QStringList of the pin ids.
* @see pins( uint pinType, const QString& portName )
*/
- QStringList pinIDs( uint pinType = 0, const QString& portName = "" );
+ TQStringList pinIDs( uint pinType = 0, const TQString& portName = "" );
/**
* Returns the number of pins of the given type(s) (which can be OR'ed together), with the given
* port name if specified, while avoiding the construction of a new PicPinMap. if pinType is 0,
* then all pin types are considered
* @see pins
*/
- int pinCount( uint pinType = 0, const QString& portName = "" );
+ int pinCount( uint pinType = 0, const TQString& portName = "" );
/**
* Returns a list of port names, eg 'PORTA', 'PORTB' for the package
*/
- QStringList portNames() const { return m_portNames; }
+ TQStringList portNames() const { return m_portNames; }
/**
* Returns the number of ports
*/
@@ -90,7 +90,7 @@ public:
private:
PicPinMap m_picPinMap;
- QStringList m_portNames;
+ TQStringList m_portNames;
int m_numPins;
};
@@ -59,30 +59,30 @@ public:
/**
- * Returns just a QStringList of the pin ids.
- * @see pins( uint pinType, const QString& portName )
+ * Returns just a TQStringList of the pin ids.
+ * @see pins( uint pinType, const TQString& portName )
*/